@@ -22,10 +22,14 @@
  *
  */
 
-#include "SavingParametersDialog.h"
+#include "TonemappingPanel/ui_SavingParametersDialog.h"
+#include "TonemappingPanel/SavingParametersDialog.h"
 
-SavingParameters::SavingParameters(QWidget *parent):
-    QDialog(parent)
-{
-    setupUi(this);
+SavingParameters::SavingParameters(QWidget *parent)
+    : QDialog(parent), m_Ui(new Ui::SavingParameters) {
+    m_Ui->setupUi(this);
 }
+
+SavingParameters::~SavingParameters() {}
+
+QString SavingParameters::getComment() { return m_Ui->comment->text(); }
